package com.jz.dmp.modules.service;

import com.jz.common.constant.JsonResult;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceNameListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListReq;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeTableInfoReq;
import com.jz.dmp.modules.model.DmpRealtimeSyncInfo;

import java.util.List;

/**
 * 实时同步任务(DmpRealtimeSyncInfo)表服务接口
 *
 * @author Bellamy
 * @since 2021-01-05 14:18:03
 */
public interface DmpRealtimeSyncInfoService {

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    DmpRealtimeSyncInfo queryById(Integer id);

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    List<DmpRealtimeSyncInfo> queryAllByLimit(int offset, int limit);

    /**
     * 新增数据
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 实例对象
     */
    DmpRealtimeSyncInfo insert(DmpRealtimeSyncInfo dmpRealtimeSyncInfo);

    /**
     * 修改数据
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 实例对象
     */
    DmpRealtimeSyncInfo update(DmpRealtimeSyncInfo dmpRealtimeSyncInfo);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    boolean deleteById(Integer id);

    /**
     * 实时同步任务列表分页查询
     *
     * @return
     */
    PageInfoResponse<RealTimeSyncListDto> queryRealTimeSyncListPage(RealTimeSyncListReq req) throws Exception;

    /**
     * 根据多个实时任务id查询任务信息
     *
     * @return
     */
    List<DmpRealtimeSyncInfo> queryListById(String[] ids) throws Exception;

    /**
     * 获取数据源和目标数据源下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    JsonResult<List<DataSourceNameListDto>> queryDatasourceNameList(String projectId, String type) throws Exception;

    /**
     * 根据数据源id获取表详细信息
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    JsonResult queryTableInfoByParams(RealTimeTableInfoReq req) throws Exception;
}